# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/utils/11_show.ipynb.

# %% auto 0
__all__ = ['show_css', 'show_cell', 'show_nb']

# %% ../../nbs/utils/11_show.ipynb 4
from IPython.display import HTML, DisplayHandle
from typing import Optional

# %% ../../nbs/utils/11_show.ipynb 5
# from nbkit.cons import ()
from .tmpl import (STYLE)
from .defs import getdef, getlexfmt
from .file import read_nb
from .node import fmt_cells, fmt_cell

# %% ../../nbs/utils/11_show.ipynb 7
def show_css(**kwargs) -> Optional[DisplayHandle]:
    '''Display CSS style for Pygments.

    Parameters
    ----------
    kwargs : dict
        Additional keyword arguments.

    Other Parameters
    ----------------
    formatter : Optional[HtmlFormatter], optional
        A Pygments HtmlFormatter object.

    Returns
    -------
    Optional[DisplayHandle]
        Display handle of the HTML output.
    '''
    fmt = getdef('formatter', **kwargs)
    style_defs = fmt.get_style_defs()    
    style = STYLE.substitute(style=style_defs)
    return display(HTML(style))

# %% ../../nbs/utils/11_show.ipynb 8
def show_cell(path: str, idx: int, **kwargs) -> Optional[DisplayHandle]:
    '''Display a specific cell in HTML format.

    Parameters
    ----------
    path : str
        Path to the notebook.
        
    idx : int
        Index of the cell to show.

    kwargs : dict
        Additional keyword arguments.

    Other Parameters
    ----------------
    html : Optional[List[str]], optional
        A list of HTML strings to add onto.

    lexer : Optional[PythonLexer], optional
        A Pygments lexer object.

    formatter : Optional[HtmlFormatter], optional
        A Pygments HtmlFormatter object.
        
    Returns
    -------
    Optional[DisplayHandle]
        Display handle of the HTML output.
    '''   
    html = fmt_cell(path, idx, **kwargs)
    return display(HTML('\n'.join(html)))

# %% ../../nbs/utils/11_show.ipynb 9
def show_nb(path: str, **kwargs) -> Optional[DisplayHandle]:
    '''
    Display a notebook in HTML format.

    Parameters
    ----------
    path : str
        The path to the notebook file. Defaults to None.

    kwargs : dict
        Additional keyword arguments.

    Other Parameters
    ----------------
    html : Optional[List[str]], optional
        A list of HTML strings to add onto.

    lexer : Optional[PythonLexer], optional
        A Pygments lexer object.

    formatter : Optional[HtmlFormatter], optional
        A Pygments HtmlFormatter object.

    Returns
    -------
    HTML
        The HTML representation of the notebook.
    '''
    html, lex, fmt = getdef('html', **kwargs), *getlexfmt(**kwargs)
    html = fmt_cells(read_nb(path), **{**kwargs, **dict(html=html, lexer=lex, formatter=fmt)})
    return display(HTML('\n'.join(html)))
