# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/utils/09_tsub.ipynb.

# %% auto 0
__all__ = ['fmt_href', 'fmt_h1', 'fmt_h2']

# %% ../../nbs/utils/09_tsub.ipynb 4
import os
from typing import List, Optional
from pstr.nchr.core import SPACE, SUNDER
from pstr.nlit.exts import EXT_IPYNB

# %% ../../nbs/utils/09_tsub.ipynb 5
from .tmpl import (HREF, HEADER,)

# %% ../../nbs/utils/09_tsub.ipynb 7
def fmt_href(file: str, path: str) -> str:
    '''Format href for given file and path.
    
    Parameters
    ----------
    file : str
        File name.
    path : str
        Path where the file resides.
        
    Returns
    -------
    str
        Formatted href string.
    '''
    return HREF.substitute(name=file, href=os.path.join(path, file))

#| export
def fmt_h1(header: str, notebooks: List[str], path: Optional[str] = None):
    '''Format H1 header and notebook links.
    
    Parameters
    ----------
    header : str
        Header string.

    notebooks : List[str]
        List of notebook files to link.

    path : str
        Path where the file resides.
        
    Returns
    -------
    List[str]
        List of formatted header and notebook links.
    
    Examples
    --------
    >>> """
    >>> # Module Name Here
    >>> > This notebook was generated from the following notebooks:
    >>> - [00_nb.ipynb](./00_nb.ipynb)
    >>> - [01_nb.ipynb](./01_nb.ipynb)
    >>> - [02_nb.ipynb](./02_nb.ipynb)
    >>> """
    '''
    if path is None and notebooks:
        path = os.path.dirname(notebooks[0])
    res = [HEADER.substitute(header=header)]
    res.extend([f'- {fmt_href(nb_str, path)}\n' for nb_str in notebooks])    
    return res

def fmt_h2(section: str) -> str:
    '''Format H2 header from section name.
    
    Parameters
    ----------
    section : str
        Section name.
        
    Returns
    -------
    str
        Formatted H2 header string.
    '''
    header = section.lstrip(SUNDER).rstrip(EXT_IPYNB).replace(SUNDER, SPACE)
    if header.split()[0].isnumeric(): 
        header = ' '.join(header.split()[1:])
    return header.title()
